@@ -14,8 +14,9 @@ import pandas as pd
 import numpy as np
 import math
 from mpl_toolkits.axes_grid1 import make_axes_locatable
+import pkg_resources
 
-__version__ = '2.2'
+__version__ = '2.3.1'
 
 def run(options = []):
 	directory = os.path.abspath(os.path.expanduser(options['directory']))
@@ -337,7 +338,9 @@ class Screen(object):
 
 			ProgressBar(index, self.numberOfConfs(), 'Extracting Models: ')
 
-		 	self.cmd.run('awk -f {pd}/OpenDiscovery/lib/extract.awk < {results}'.format(pd=self.protocol_dir, results=lig_name + ".pdbqt"))
+		 	#self.cmd.run('awk -f {pd}/OpenDiscovery/lib/extract.awk < {results}'.format(pd=self.protocol_dir, results=lig_name + ".pdbqt"))
+			awk_location = pkg_resources.resource_filename('OpenDiscovery', 'lib/extract.awk')
+			self.cmd.run('awk -f {awk} < {results}'.format(awk=awk_location, results=lig_name + ".pdbqt"))
 
 		 	# make new folder for them
 		 	makeFolder(lig_name)
@@ -351,8 +354,6 @@ class Screen(object):
 		 	except:
 		 		pass
 
-			os.chdir(self.protocol_dir)
-
 	def gatherResults(self):
 		""" Extracts the energy information from vina logs, and adds it to a sorted csv. """
 
